<?php

namespace app\youzan\controller;

use app\admin\controller\Base;
use app\youzan\logic\Cat;
use app\youzan\logic\Tag;
use app\youzan\logic\Goodup;
use think\facade\Validate;

//有赞对接类
class Index extends Base
{

    //获取有赞的类目列表
    public function getYzCatList()
    {

        $parent_cid = $this->request->post('parent_cid/d', 0, 'trim');

        $rs = Cat::getYzCatList($parent_cid);

        return app_show(0, '请求成功', $rs);

    }

    //获取有赞的标签列表
    public function getYzTagList()
    {

        $rs = Tag::getYzTagList();

        return app_show(0, '请求成功', $rs);

    }

    //审核并将商品推送到有赞平台
    public function checkExamstatus()
    {
        $param = $this->request->only(['platform_youzan_id', 'exam_status', 'reject_reason', 'yz_cat_id', 'is_support_barter', 'good_ladder_id', 'final_price', 'token', 'start_sale_num', 'tags' => []], 'post', 'trim');

        $val = Validate::rule([
            'platform_youzan_id|商品上线记录ID' => 'require|number|gt:0',
            'exam_status|审核状态' => 'require|number|in:1,2',
            'reject_reason|驳回原因' => 'requireIf:exam_status,2',
            'yz_cat_id|有赞分类' => 'requireIf:exam_status,1|number|gt:0',
            'is_support_barter|是否可退货' => 'requireIf:exam_status,1|number|in:0,1',
            'good_ladder_id|商品阶梯记录id' => 'requireIf:exam_status,1|number|gt:0',
            'final_price|最终售价' => 'requireIf:exam_status,1|float|elt:9999999',
            'start_sale_num|有赞起售数' => 'requireIf:exam_status,1|number',
            'token' => 'require',
        ]);

        if ($val->check($param)) return Goodup::youzanGoodUpOnline($param['platform_youzan_id'], $param);
        else return error_show(1005, $val->getError());
    }

    //有赞商品重新上线
    public function goodupOnlineAgain()
    {
        $param = $this->request->only(['token', 'platform_youzan_id'], 'post', 'trim');
        $val = Validate::rule([
            'platform_youzan_id|商品上线记录ID' => 'require|number|gt:0',
            'token' => 'require',
        ]);

        if ($val->check($param)) return Goodup::goodupOnlineAgain($param['platform_youzan_id'], $param['token']);
        else return error_show(1005, $val->getError());

    }

    //商品上线详情
    public function getYzGoodupInfo()
    {
        $platform_youzan_id = $this->request->post('platform_youzan_id/d', 0, 'trim');
        return Goodup::getYzGoodupInfo($platform_youzan_id);
    }

    //商品下线
    public function youzanOffline()
    {
        $param = $this->request->only(['platform_youzan_id', 'token', 'offline_reason_id', 'offline_remark' => ''], 'post', 'trim');

        $val = Validate::rule([
            'platform_youzan_id|有赞商品上线记录id' => 'require|number|gt:0',
            'offline_reason_id|商品下线原因id' => 'require|number|gt:0',
            'offline_remark|商品下线备注' => 'require|max:255',
            'token' => 'require',
        ]);

        if ($val->check($param)) return Goodup::youzanGoodOffline($param['platform_youzan_id'], $param);
        else return error_show(1005, $val->getError());
    }

    //有赞下线商品列表
    public function youzanOfflineList()
    {

        $param = $this->request->only(['start_date' => '', 'end_date' => '', 'creater' => '', 'page' => 1, 'size' => 15], 'post', 'trim');

        return Goodup::youzanOfflineList($param);

    }

    //有赞下线商品详情
    public function youzanOfflineDetail()
    {

        $platform_youzan_id = $this->request->param('platform_youzan_id/d', 0, 'trim');

        return Goodup::youzanOfflineDetail($platform_youzan_id);


    }


}